@@ -16,19 +16,18 @@ my $wDisplay = Prima::MainWindow->create(
  my $smiley_plot_type = pt::CallBack(
  	base_class => 'PDL::Graphics::Prima::PlotType::Pair::Blobs',
  	draw => sub {
- 		my ($self, $canvas) = @_;
+ 		my ($self, $canvas, $ratio) = @_;
  		
  		# Retrieve the data from the dataset:
- 		my $widget = $self->widget;
- 		my ($xs, $ys) = $self->dataset->get_data_as_pixels($widget);
+ 		my ($xs, $ys) = $self->dataset->get_data_as_pixels($ratio);
  		
  		# Draw the smileys:
- 		$widget->pdl_ellipses($xs, $ys, 20, 20);	# face
- 		$widget->pdl_fill_ellipses($xs - 5, $ys + 4, 2, 2);	# left eye
- 		$widget->pdl_fill_ellipses($xs + 5, $ys + 4, 2, 2); # right eye
- 		$widget->pdl_fill_chords($xs, $ys, 10, 10, 180, 360); # smiling mouth
+ 		$canvas->pdl_ellipses($xs, $ys, 20, 20);	# face
+ 		$canvas->pdl_fill_ellipses($xs - 5, $ys + 4, 2, 2);	# left eye
+ 		$canvas->pdl_fill_ellipses($xs + 5, $ys + 4, 2, 2); # right eye
+ 		$canvas->pdl_arcs($xs, $ys, 10, 10, 200, 340); # smiling mouth
  	},
- 	radius => 20,	# be sure to coordinate with pdl_ellipses, above
+ 	radius => 10,	# be sure to coordinate with pdl_ellipses, above
  );
 
 
